%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%               BACKHOE PRESSURE DATA PLOT FILE
%
% This file plots the pressure data taken from the backhoe
%
% The format of the data files are all the same as follows:
%
%      data = [ t(n,1) ycdes(n,4) Us(n,4) yc(n,4) p(n,10) ];
%
% where each group of vectors v(n,c) is n rows long and c columns wide.
%
% t = time
% ycdes = desired (reference) cylinder lengths
% Us = valve command (3 < Us < 9) [V]
% yc = actual cylinder lengths
% p = pressures
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all ; close all ; clc ;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                    Swing bounce data
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% set up the figure
figure
subplot(5,1,1)
title('Swing')
ylabel('swing angle [deg]')
ylim([-35 35])
hold on

subplot(5,1,2)
ylabel('pressure [psi]')
ylim([0 2500])
hold on

subplot(5,1,3)
ylabel('pressure [psi]')
ylim([0 2500])
hold on

subplot(5,1,4)
ylabel('pressure [psi]')
ylim([0 2500])
hold on

subplot(5,1,5)
ylabel('valve command [V]')
hold on

% plot the closed-loop data
load data_swing_PVG_FB
data=data(1:20000,:);

t=data(:,1)-data(1,1);
qdes1=data(:,2);
q1=data(:,10);
pc1=data(:,14)*375-750;
pr1=data(:,15)*375-750;
Us1=data(:,6);

subplot(5,1,1)
plot(t,q1*180/pi,'r')
plot(t,qdes1*180/pi,'b--')

subplot(5,1,2)
plot(t,pc1,'r')
plot(t,pr1,'b')
legend('cap-side (closed-loop)','rod-side (closed-loop)')

subplot(5,1,5)
plot(t,Us1,'r')
plot([t(1) t(end)],[6 6],'k')
legend('closed-loop command','neutral')

% plot the manual PVG data
clear all
load data_swing_PVG_Man
data=data(1:20000,:);

t=data(:,1)-data(1,1);
q1=data(:,10);
pc1=data(:,14)*375-750;
pr1=data(:,15)*375-750;

subplot(5,1,1)
plot(t,q1*180/pi,'m')

subplot(5,1,3)
plot(t,pc1,'r')
plot(t,pr1,'b')
legend('cap-side (PVG manual)','rod-side (PVG manual)')

% plot the manual Gresen data
clear all
load data_swing_Gresen_Man
data=data(1:20000,:);

t=data(:,1)-data(1,1);
q1=data(:,10);
pc1=data(:,14)*375-750;
pr1=data(:,15)*375-750;

subplot(5,1,1)
plot(t,q1*180/pi,'b')
legend('closed-loop','closed-loop reference','PVG manual','Gresen manual')

subplot(5,1,4)
plot(t,pc1,'r')
plot(t,pr1,'b')
legend('cap-side (Gresen manual)','rod-side (Gresen manual)')


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                Boom bounce data
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all

% set up the figure
figure
subplot(5,1,1)
title('Boom')
ylabel('boom cylinder [in]')
ylim([25 35])
hold on

subplot(5,1,2)
ylabel('pressure [psi]')
ylim([0 1200])
hold on

subplot(5,1,3)
ylabel('pressure [psi]')
ylim([0 1200])
hold on

subplot(5,1,4)
ylabel('pressure [psi]')
ylim([0 1200])
hold on

subplot(5,1,5)
ylabel('valve command [V]')
hold on

% plot the closed-loop data
load data_boom_PVG_FB
data=data(1:20000,:);

t=data(:,1)-data(1,1);
ycdes3=data(:,3);
yc3=data(:,11);
pc3=data(:,17)*375-750;
pr3=data(:,16)*375-750;
Us2=data(:,7);

subplot(5,1,1)
plot(t,yc3,'r')
plot(t,ycdes3,'b--')

subplot(5,1,2)
plot(t,pc3,'r')
plot(t,pr3,'b')
legend('cap-side (closed-loop)','rod-side (closed-loop)')

subplot(5,1,5)
plot(t,Us2,'r')
plot([t(1) t(end)],[6 6],'k')
legend('closed-loop command','neutral')

% plot the manual PVG data
clear all
load data_boom_PVG_Man
data=data(1:20000,:);

t=data(:,1)-data(1,1);
yc3=data(:,11);
pc3=data(:,17)*375-750;
pr3=data(:,16)*375-750;

subplot(5,1,1)
plot(t,yc3,'m')

subplot(5,1,3)
plot(t,pc3,'r')
plot(t,pr3,'b')
legend('cap-side (PVG manual)','rod-side (PVG manual)')

% plot the manual Gresen data
clear all
load data_boom_Gresen_Man
data=data(1:20000,:);

t=data(:,1)-data(1,1);
yc3=data(:,11);
pc3=data(:,17)*375-750;
pr3=data(:,16)*375-750;

subplot(5,1,1)
plot(t,yc3,'b')
legend('closed-loop output','closed-loop reference','PVG manual','Gresen manual')

subplot(5,1,4)
plot(t,pc3,'r')
plot(t,pr3,'b')
legend('cap-side (Gresen manual)','rod-side (Gresen manual)')


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                    Swing Step Response
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all
str1='load data_swing_PVG_OL_Full_';
str2=strvcat('pos1','pos2','pos3','neg1','neg2','neg3');
c=['b','m','r','g','c','k'];

figure
subplot(4,1,1)
title('Swing cylinder step response')
ylabel('valve command [V]')
hold on

subplot(4,1,2)
ylabel('cap-side pressure [psi]')
ylim([0 2500])
hold on

subplot(4,1,3)
ylabel('rod-side pressure [psi]')
ylim([0 3000])
hold on

subplot(4,1,4)
ylabel('(rel) swing angle [deg]')
xlabel('time [s]')
hold on

for i=1:6
    eval(strcat(str1,str2(i,:)));
    data=data(7000:end,:);
    t=data(:,1)-data(1,1);
    Us=data(:,6);
    q1=data(:,10)-data(1,10);
    pc=data(:,14)*375-750;
    pr=data(:,15)*375-750;
    
    subplot(4,1,1)
    plot(t,Us,c(i))
    ylim([2 10])
    
    subplot(4,1,2)
    plot(t,pc,c(i))

    subplot(4,1,3)
    plot(t,pr,c(i))
    
    subplot(4,1,4)
    plot(t,q1*180/pi,c(i))
end
subplot(4,1,1)
legend('+1 V','+2 V','+3 V','-1 V','-2 V','-3 V')

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                    Boom Step Response
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all
str1='load data_boom_PVG_OL_Full_';
str2=strvcat('pos1','pos2','pos3','neg1','neg2','neg3');
c=['b','m','r','g','c','k'];

figure
subplot(4,1,1)
title('Boom cylinder step response')
ylabel('valve command [V]')
hold on

subplot(4,1,2)
ylabel('cap-side pressure [psi]')
ylim([0 800])
hold on

subplot(4,1,3)
ylabel('rod-side pressure [psi]')
ylim([0 1600])
hold on

subplot(4,1,4)
ylabel('cyl length [in]')
xlabel('time [s]')
hold on

for i=1:6
    eval(strcat(str1,str2(i,:)));
    data=data(7000:end,:);
    t=data(:,1)-data(1,1);
    Us=data(:,7);
    yc3=data(:,11);
    pc=data(:,17)*375-750;
    pr=data(:,16)*375-750;
    
    subplot(4,1,1)
    plot(t,Us,c(i))
    ylim([2 10])
    
    subplot(4,1,2)
    plot(t,pc,c(i))

    subplot(4,1,3)
    plot(t,pr,c(i))
    
    subplot(4,1,4)
    plot(t,yc3,c(i))
end
subplot(4,1,1)
legend('+1 V','+2 V','+3 V','-1 V','-2 V','-3 V')

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                   Full-shift manual swing response
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all

% set up the figure
figure

subplot(3,1,1)
title('Full-shift manual swing response')
ylabel('swing angle [deg]')
ylim([-60 60])
hold on 

subplot(3,1,2)
ylabel('pressure [psi]')
ylim([0 2800])
hold on

subplot(3,1,3)
ylabel('pressure [psi]')
ylim([0 2800])
hold on


% plot the PVG data
clear all
load data_swing_PVG_Man_Full
data=data(15000:30000,:);

t=data(:,1)-data(1,1);
q1=data(:,10);
pc1=data(:,14)*375-750;
pr1=data(:,15)*375-750;

subplot(3,1,1)
plot(t,q1*180/pi,'r')

subplot(3,1,2)
plot(t,pc1,'r')
plot(t,pr1,'b')
legend('cap-side (PVG)','rod-side (PVG)')

% plot the Gresen data
clear all
load data_swing_Gresen_Man_Full

t=data(:,1)-data(1,1);
q1=data(:,10);
pc1=data(:,14)*375-750;
pr1=data(:,15)*375-750;

subplot(3,1,1)
plot(t,q1*180/pi,'b')
legend('PVG valve','Gresen valve')

subplot(3,1,3)
plot(t,pc1,'r')
plot(t,pr1,'b')
legend('cap-side (Gresen)','rod-side (Gresen)')

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                   Full-shift manual boom response
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all

% set up the figure
figure
subplot(3,1,1)
title('Full-shift manual boom response')
ylabel('boom cyl [in]') 
xlim([0 12])
hold on

subplot(3,1,2)
ylabel('pressure [psi]')
ylim([0 2500])
xlim([0 12])
hold on

subplot(3,1,3)
ylabel('pressure [psi]')
ylim([0 2500])
xlim([0 12])
hold on 

% plot the PVG data
clear all
load data_boom_PVG_Man_Full
data=data(12000:end,:);

t=data(:,1)-data(1,1);
yc3=data(:,11);
pc3=data(:,17)*375-750;
pr3=data(:,16)*375-750;

subplot(3,1,1)
plot(t,yc3,'r')

subplot(3,1,2)
plot(t,pc3,'r')
plot(t,pr3,'b')
legend('cap-side (PVG)','rod-side (PVG)')

% plot the Gresen data
clear all
load data_boom_Gresen_Man_Full
data=data(2000:end,:);

t=data(:,1)-data(1,1);
yc3=data(:,11);
pc3=data(:,17)*375-750;
pr3=data(:,16)*375-750;

subplot(3,1,1)
plot(t,yc3,'b')
legend('PVG valve','Gresen valve')

subplot(3,1,3)
plot(t,pc3,'r')
plot(t,pr3,'b')
legend('cap-side (Gresen)','rod-side (Gresen)')